@@ -3,7 +3,7 @@ var indexSectionsWithContent =
   0: "abcdefgiklmnoprstuw",
   1: "bcdegiklmnprsuw",
   2: "c",
-  3: "c",
+  3: "o",
   4: "abcdegiklmnoprsuw",
   5: "acfrt"
 };
